# Multi-News Dataset

Multi-News consists of news articles and human-written summaries of these
articles from the news site `newser.com`. Each summary is professionally written
by editors and includes links to the original articles cited.

This is the first large-scale dataset for multi-document summarization on news
articles.

Each record has two features:

* `document`: Texts of news articles, separated by special token "|||||".
* `summary`: Summary of the news.
